SimpleMetricBuilder

Struct SimpleMetricBuilder 

pub struct SimpleMetricBuilder<T, H> { /* private fields */ }
A Metric Builder to configure a metric to add to a SimpleMetricManager

Implementations

Source

impl<T, H> SimpleMetricBuilder<T, H>
where T: MetricValue + Clone + Send + 'static,

pub fn new<S: Into<String>>(name: S, value: T) -> Self

Create a new metric builder instance

pub fn with_cmd_handler<F, Fut>(self, cb: F) -> Self
where F: Fn(SimpleMetricManager<H>, SimpleManagerMetric<T, H>, Option<T>) -> Fut + Send + Sync + 'static, Fut: Future<Output = ()> + Send + 'static,

Set a handler which will be called when command messages for this metric are received.

The command handler is an async function that receives the manager, the metric, and an optional new value for the metric. If the value is “None” that indicates the CMD metric’s ‘is_null’ field was true

pub fn use_alias(self, use_alias: bool) -> Self

Set if the metric should use an alias. Defaults to true.