BirthInitializer

Struct BirthInitializer 

pub struct BirthInitializer { /* private fields */ }
A struct used to register metrics to be included in a node or devices birth.

Implementations

Source

impl BirthInitializer

pub fn register_metric<T>( &mut self, details: BirthMetricDetails<T>, ) -> Result<MetricToken<T>, BirthMetricError>
where T: MetricValue,

Register a metric for the birth of the node/device

Metric names must be unique. Note: For metrics with Template datatypes, use Self::register_template_metric instead.

pub fn register_template_metric<T>( &mut self, details: BirthMetricDetails<T>, ) -> Result<MetricToken<T>, BirthMetricError>
where T: Template,

Register a new template metric

Note: Templates must have been registered with TemplateRegistry See Self::register_metric for further details