Struct DeviceHandle

pub struct DeviceHandle { /* private fields */ }
A handle for interacting with an Edge Device

Implementations

Source

impl DeviceHandle

pub async fn enable(&self)

Enabled the device

Will attempt to birth the device. If the node is not online, the device will be birthed when it is next online.

pub async fn rebirth(&self)

Rebirth the device

Manually trigger a rebirth for the device.

pub async fn disable(&self)

Disable the device

Will produce a death message for the device. The node will no longer attempt to birth the device when it comes online.