NodeHandle

Struct NodeHandle 

pub struct NodeHandle { /* private fields */ }
A handle for interacting with the Edge Node.

NodeHandle provides an interface for interacting with an edge node, including device management, node lifecycle operations, and metric publishing.

Implementations

Source

impl NodeHandle

pub async fn cancel(&self)

Stop all operations, sending a death certificate and disconnect from the broker.

This will cancel EoN::run()

pub fn rebirth(&self)

Manually trigger a rebirth for the node

pub fn register_device<S, M>( &self, name: S, dev_impl: M, ) -> Result<DeviceHandle, DeviceRegistrationError>
where S: Into<String>, M: DeviceMetricManager + Send + Sync + 'static,

Registers a new device with the node.

Returns an error if:

  • A device with the same name is already registered
  • The device name is invalid
pub async fn unregister_device(&self, handle: DeviceHandle)

Unregister a device using it’s handle.

pub async fn unregister_device_named(&self, name: &String)

Unregister a device using it’s name.