pub struct TemplateRegistry { /* private fields */ }Expand description
A struct representing a collection of Template Definitions for a Node
Used to manage the template definitions for the node. A definition must be included in the registry in order to register a metric that has a template datatype with a BirthInitializer.
When a Node generates a birth message, a template definition for each templates registered with this structure will be included in the Nodes birth message. srad_types::TemplateMetadata::template_definition_metric_name for the type is used to define the name of the metric that represents the template definition. srad_types::Template::template_definition() is used to generate the definition used for the metrics value.
For templates which use another template as one of it’s metrics, the template used as a field must be registered first.
This registry is checked any time a metric that uses a template as the type for its value is registered for birth.
Implementations