pub struct SimpleMetricBuilder<T, H> { /* private fields */ }Expand description
A Metric Builder to configure a metric to add to a SimpleMetricManager
Implementations
Sourceimpl<T, H> SimpleMetricBuilder<T, H>
impl<T, H> SimpleMetricBuilder<T, H>
Sourcepub fn with_cmd_handler<F, Fut>(self, cb: F) -> Selfwhere
F: Fn(SimpleMetricManager<H>, SimpleManagerMetric<T, H>, Option<T>) -> Fut + Send + Sync + 'static,
Fut: Future<Output = ()> + Send + 'static,
pub fn with_cmd_handler<F, Fut>(self, cb: F) -> Selfwhere
F: Fn(SimpleMetricManager<H>, SimpleManagerMetric<T, H>, Option<T>) -> Fut + Send + Sync + 'static,
Fut: Future<Output = ()> + Send + 'static,
Set a handler which will be called when command messages for this metric are received.
The command handler is an async function that receives the manager, the metric, and an optional new value for the metric. If the value is “None” that indicates the CMD metric’s ‘is_null’ field was true