pub struct SimpleMetricManager<H> { /* private fields */ }Expand description
A MetricManager implementation that provides simple metric registration and handling.
SimpleMetricManager provides a simple way to manage metrics with support for
command callbacks and metric publishing.
Example
use srad_eon::{SimpleMetricManager, SimpleMetricBuilder};
//Create a new simple metric manager
let manager = SimpleMetricManager::new();
// Assume we successfully create a device with a SimpleMetricManager as it's metrics manager
create_device_with_manager(&manager);
// Register a simple metric
let counter = manager.register_metric(SimpleMetricBuilder::new("Counter", 0 as i32)).unwrap();
// Register a metric with a command handler
let temperature = manager.register_metric(
SimpleMetricBuilder::new("temperature", 25.5)
.with_cmd_handler(
|mgr, metric, new_value| async move {
if let Some(value) = new_value {
mgr.publish_metric(metric.update(|x|{ *x = value })).await;
}
}
)
);Implementations
Sourceimpl<H> SimpleMetricManager<H>
impl<H> SimpleMetricManager<H>
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new empty SimpleMetricManager.
This initialises a new metric manager with no registered metrics.
Sourcepub fn register_metric<T>(
&self,
builder: SimpleMetricBuilder<T, H>,
) -> Option<SimpleManagerMetric<T, H>>
pub fn register_metric<T>( &self, builder: SimpleMetricBuilder<T, H>, ) -> Option<SimpleManagerMetric<T, H>>
Registers a new metric from the builders settings.
Returns None if a metric with the same name already exists, otherwise
returns the newly created metric.
Sourcepub async fn publish_metric(
&self,
metric: SimpleManagerPublishMetric,
) -> Result<(), PublishError>
pub async fn publish_metric( &self, metric: SimpleManagerPublishMetric, ) -> Result<(), PublishError>
Publishes a single metric.
Returns an error if the metric was not published.
Sourcepub async fn publish_metrics(
&self,
metrics: Vec<SimpleManagerPublishMetric>,
) -> Result<(), PublishError>
pub async fn publish_metrics( &self, metrics: Vec<SimpleManagerPublishMetric>, ) -> Result<(), PublishError>
Publishes a multiple metric in a single batch.
Returns an error if the metrics were not published.